### Neuroseries

This package includes tools to process neural data series,
providing function for handling of timestamped data, and for irregular 
intervals. It is based on Pandas for most functionality, enhanced in the 
areas where Pandas does not satisfy the needs of the neural data analyst.

This package requires Python 3. The current version, 0.3.1 is compatible with pandas 0.23 and
has been tested with Python 3.7.
Look at the test suite for use examples.